Learn R Programming

klausuR (version 0.12-5)

antworten.mufo: Sample dataset: antworten.mufo

Description

Sample data of a multiple choice test with two test forms.

Usage

data(antworten.mufo)

Arguments

encoding

UTF-8

source

The data was taken from a final exam test in differential psychology at the Institute for Experimental Psychology of the Heinrich-Heine-University Düsseldorf, summer term 2009.

Details

The data is actually the same as antworten. But in this object the items of the last 10 test subjects were reversed, hence this is test form ''b''. As a convenience, a matrix called corr.key is also included. This data can be used to test klausur.mufo.

Examples

Run this code
data(antworten.mufo)

Run the code above in your browser using DataLab