Try this function to combine results from an evaluated test into a matrix and export it to a table, e.g. to import in other software products. It can be particularily helpful for ET/NRET coded tests, if you want to compare the results of different valid scoring functions.
grand.table(
NR.res = NULL,
NRET.res = NULL,
NRETp.res = NULL,
ET.res = NULL,
rescale = TRUE,
file = NULL,
csv2 = TRUE,
encoding = "CP1252",
...
)An object of class klausuR which was evaluated according to the NR scoring policy.
Usual MC tests must be given as NR.res, too.
An object of class klausuR which was evaluated according to the NRET scoring policy.
An object of class klausuR which was evaluated according to the NRET+ scoring policy.
An object of class klausuR which was evaluated according to the ET scoring policy.
Logical,
whether ET/NRET scaled results should be rescaled by nret.rescale.
A character string giving a file name to save to. If NULL,
no file will be written.
Logical. If FALSE,
write.csv will be used instead of write.csv2.
Encoding of the exported table.
Additional options for write.csv/write.csv2.
A data.frame.