Learn R Programming

klausuR (version 0.12-5)

klausuR-package: Multiple Choice Test Evaluation.

Description

Multiple Choice Test Evaluation.

Arguments

Details

ll{ Package: klausuR Type: Package Version: 0.12-5 Date: 2012-03-10 Depends: R (>= 2.9.0),xtable,psychometric,methods,graphics,tools Enhances: rkward Encoding: UTF-8 License: GPL (>= 3) LazyLoad: yes URL: http://r-forge.r-project.org/projects/klausur }

A set of functions designed to quickly generate results of a multiple choice test. Generates detailed global results, lists for anonymous feedback and personalised result feedback (in LaTeX and/or PDF format), as well as item statistics like Cronbach's alpha or disciminatory power.