Learn R Programming

klausuR (version 0.12-5)

klausur: Evaluate multiple choice tests

Usage

klausur(data, marks = NULL, mark.labels = NULL,
    items = NULL, wght = NULL, score = "solved",
    matn = NULL, na.rm = TRUE, cronbach = TRUE,
    item.analysis = TRUE, sort.by = "Name", maxp = NULL)

Arguments

data
An object of class klausuR.answ-class.
marks
A vector assigning marks to points achieved (see details). Alternatively, set it to "suggest" to let klausur.gen.marks calculate suggestions under the
mark.labels
If marks="suggest", use these as the marks you want to give.
items
Indices of a subset of variables in data to be taken as items.
wght
A vector with weights for each item (named also according to Item###}). If \code{NULL}, the value from the data object will be used.

score{Specify the scoring policy, must be one of "solved" (de

p
N
n
0
*

strong

  • Marks
  • assigned marks

See Also

klausur.data, klausur.report, compare, klausur.gen, klausur.gen.marks, klausur.gen.corr, plot, psychometric

Examples

Run this code
data(antworten)

# vector with correct answers:
richtig <- c(Item01=3, Item02=2, Item03=2, Item04=2, Item05=4,
	Item06=3, Item07=4, Item08=1, Item09=2, Item10=2, Item11=4,
	Item12=4, Item13=2, Item14=3, Item15=2, Item16=3, Item17=4,
	Item18=4, Item19=3, Item20=5, Item21=3, Item22=3, Item23=1,
	Item24=3, Item25=1, Item26=3, Item27=5, Item28=3, Item29=4,
	Item30=4, Item31=13, Item32=234)

# vector with assignement of marks:
notenschluessel <- c()
# scheme of assignments: marks[points_from:to] <- mark
notenschluessel[0:12]  <- 5.0
notenschluessel[13:15] <- 4.0
notenschluessel[16:18] <- 3.7
notenschluessel[19:20] <- 3.3
notenschluessel[21]    <- 3.0
notenschluessel[22]    <- 2.7
notenschluessel[23]    <- 2.3
notenschluessel[24]    <- 2.0
notenschluessel[25:26] <- 1.7
notenschluessel[27:29] <- 1.3
notenschluessel[30:32] <- 1.0

# now combine all test data into one object of class klausur.answ
data.obj <- klausur.data(answ=antworten, corr=richtig, marks=notenschluessel)

# if that went well, get the test results
klsr.obj <- klausur(data.obj)

############################
	# example for an NRET test
############################
# load sampla data in SPSS format
data(spss.data)
# define correct answers
spss.corr <- c(
		item01=2, item02=3, item03=3, item04=3, item05=2,
		item06=2, item07=3, item08=1, item09=1, item10=2)

# convert into klausuR type coding
klausuR.data <- nret.translator(spss.data, spss="in")
klausuR.corr <- nret.translator(spss.corr, spss="in", corr=TRUE,
  num.alt=3, spss.prefix=c(corr="item"))
# now create the data object; "Nickname" must be renamed
data.obj <- klausur.data(answ=klausuR.data, corr=klausuR.corr,
  rename=c(Pseudonym="Nickname"))

	# finally, the test can be evaluated, using the scoring functions available
NRET.results <- klausur(data.obj, marks="suggest", mark.labels=11, score="NRET")
NRETplus.results <- klausur(data.obj, marks="suggest", mark.labels=11, score="NRET+")
NR.results <- klausur(data.obj, marks="suggest", mark.labels=11, score="NR")
ET.results <- klausur(data.obj, marks="suggest", mark.labels=11, score="ET")

Run the code above in your browser using DataLab