Learn R Programming

klausuR (version 0.12-5)

klausur.data: A function to create data objects with given and correct answers to a test.

Usage

klausur.data(answ, corr, items = NULL, marks = NULL,
    wght = NULL, corr.key = NULL, rename = c(),
    dummies = c(), disc.misc = FALSE, na.rm = TRUE,
    item.prefix = c(), sort.by = "Name", maxp = NULL)

Arguments

answ
A data.frame which has to include at least these variables: No, Name, FirstName, MatrNo, as well as Pseudonym (optional) and variabl