klausur.klausur.gen.marks(mark.labels = NULL, answ = NULL,
wght = NULL, suggest = list(mean = NULL, sd = NULL),
minp = 0)klausur), e.g.
your observation data, or an integer representing the
maximum score of the test. If NULL, you will be asked for
mean and
sd. If both are not NULL, this function will
suggest marks for achieved points assuming normal
distribution. That is, "mean" and "sd" should be set to
the corresponding values of the testmark.labels is set to one of the arguments 6,
11, 16, "DIHK", "UK", "USA" or "A", often used schemes
for marks will be used as a preset. In case of
mark.labels=6, marks will go from 1 (best) to 6
(failed), as widely used in German schools. In case of
mark.labels=11, marks will range from 1.0 (best)
to 5.0 (failed), with the marks 1 through 3 being split
into three decimal steps .0, .3 and .7, as is often used
in academic institutions. In case of
mark.labels=16, marks will be a range of points
from 15 (best) to 0 (failed), as often used in German
gymnasiums. If mark.labels="A", marks A to F are
given. For the other cases some more probably useful assumptions
are being made, which percentage of achieved points leads
to which mark. If mark.labels="DIHK", marks will
be 1 through 6, and calculated according to usual
standards of the Deutsche Industrie- und Handelskammer (1
> 92%, 2 > 81%, 3 > 67%, 4 > 50%, 5 > 30%, 6 below
that). If mark.labels="UK", marks are A > 90%, B
> 65%, C > 35%, D > 10% and E below that, and for
mark.labels="USA" it's A > 90%, B > 80%, C >
70%, D > 60% and F below that. Please note that the
percentages indicate individual test results and not "the
best X percent of the sample". If you'd rather use your
own system, either declare it as a vector, or leave as
NULL, and you'll be asked (be sure to begin with
the worst mark!).
The parameter answ is quite versatile as well. You
can just feed it your observation data, if it complies
with the naming scheme for items (Item###}, see
also klausur.gen), and
klausur.gen.marks will calculate the maximum score
automatically. Or you assign the maximum directly as an
integer value.
Another feature can be toggled with the parameter
suggest. If you feed it with the mean and standard
deviation values of your test's results, marks are
automatically assigned to the achieved score under the
assumption of normal distribution. Please understand that
the naming "suggest" is not an accident! This is only a
suggestion, please review it, tweak it, revise it, until
it fits your needs. However, this feature can directly be
called by klausur.
klausur