Learn R Programming

klausuR (version 0.12-5)

klausur.mufo: Evaluate multiple choice tests with several test forms

Usage

klausur.mufo(data, marks = NULL, mark.labels = NULL,
    items = NULL, wght = NULL, score = "solved",
    matn = NULL, na.rm = TRUE, cronbach = TRUE,
    item.analysis = TRUE)

Arguments

data
An object of class klausuR.answ-class.
marks
A vector assigning marks to points achieved (see details). Alternatively, set it to "suggest" to let klausur.gen.marks calculate suggestions under the
mark.labels
If marks="suggest", use these as the marks you want to give.
items
Indices of a subset of variables in answ to be taken as items.
wght
A vector with weights for each item (named also according to Item###}). If \code{NULL}, the value from the data object will be used.

score{Specify the scoring policy, must be one of "solved" (de