Learn R Programming

klausuR (version 0.12-5)

show: Show methods for objects of class klausuR and klausuR.mult

Description

Show methods for S4 objects of classes klausuR and klausuR.mult

Arguments

object
An object of class klausuR or klausuR.mult

Details

Print a nice summary of the slots results, anon, cronbach and item.analysis. If object is of class klausuR.mult, the global results for tests with several test forms are evaluated.

See Also

klausur, klausur.mufo

Examples

Run this code
klausur(data.obj)

# multiple test forms
klausur.mufo(data.obj, marks=notenschluessel)

Run the code above in your browser using DataLab