Learn R Programming

klausuR (version 0.12-5)

sort.klausuR: Sort method for objects of class klausuR

Description

Sort method for S4 objects of class klausuR

Arguments

x
An object of class klausuR
decreasing
Logical, whether sorting should be sone increasing or decreasing.
sort.by
An optional character string naming a variable to sort the results by. Defaults to c(), i.e. no re-ordering.

Details

Returns the given object, with global results and anonymized results sorted by the given variable.

See Also

klausur

Examples

Run this code
klsr.obj <- klausur(data.obj)
sort(klsr.obj, sort.by="Points")

Run the code above in your browser using DataLab