antworten: Sample dataset: antworten
Description
Sample data of a multiple choice test.encoding
UTF-8source
The data was taken from a final exam test in differential psychology at the Institute for Experimental
Psychology of the Heinrich-Heine-University Düsseldorf, summer term 2009.Details
This data was anonymised and Items 31 and 32 modified, to demonstrate items with multiple answers as well.