antworten.mufo: Sample dataset: antworten.mufo
Description
Sample data of a multiple choice test with two test forms.Usage
data(antworten.mufo)
encoding
UTF-8source
The data was taken from a final exam test in differential psychology at the Institute for Experimental
Psychology of the Heinrich-Heine-University Düsseldorf, summer term 2009.Details
The data is actually the same as antworten. But in this object the items of the last 10 test
subjects were reversed, hence this is test form ''b''. As a convenience, a matrix called corr.key
is also included. This data can be used to test klausur.mufo.