spss.data: Sample dataset: spss.data
Description
Sample data of a test with NRET data.encoding
UTF-8source
The data was taken from a final exam test in diagnostic methods at the Institute for Experimental
Psychology of the Heinrich-Heine-University Düsseldorf, summer term 2011.Details
This data was anonymised and combined from originally 51 observations. See nret.translator on details
how the answers are coded.